Struct amazon_sp_fba_inventory::models::researching_quantity_entry::ResearchingQuantityEntry
source · [−]Expand description
ResearchingQuantityEntry : The misplaced or warehouse damaged inventory that is actively being confirmed at our fulfillment centers.
Fields
name: NameThe duration of the research.
quantity: i32The number of units.
Implementations
sourceimpl ResearchingQuantityEntry
impl ResearchingQuantityEntry
sourcepub fn new(name: Name, quantity: i32) -> ResearchingQuantityEntry
pub fn new(name: Name, quantity: i32) -> ResearchingQuantityEntry
The misplaced or warehouse damaged inventory that is actively being confirmed at our fulfillment centers.